@@ -1,6 +1,6 @@
 """Contains constants."""
 
-from typing import Final
+from typing import Final, List
 
 from . import data_types
 
@@ -137,7 +137,7 @@ STATUSES: Final = (
     DATA_WATER_HEATER_STATUS,
 )
 
-DEVICE_DATA: list = [
+DEVICE_DATA: List[str] = [
     DATA_ALARMS,
     DATA_FAN_POWER,
     DATA_FRAMES,
@@ -339,7 +339,7 @@ DATA_TYPES: Final = (
     data_types.IPv6,
 )
 
-REGDATA_ELEMENTS: Final = {
+REGDATA_SCHEMA: Final = {
     1792: DATA_MODE,
     1024: TEMPERATURES[0],
     1026: TEMPERATURES[1],
@@ -348,6 +348,9 @@ REGDATA_ELEMENTS: Final = {
     1030: TEMPERATURES[5],
     1280: DATA_HEATING_TARGET,
     1281: DATA_WATER_HEATER_TARGET,
+    1536: OUTPUTS[0],
+    1538: OUTPUTS[1],
     1541: OUTPUTS[2],
     1542: OUTPUTS[3],
+    3: OUTPUTS[5],
 }
