@@ -1,7 +1,7 @@
 """Contains classes for supported devices."""
 from __future__ import annotations
 
-from typing import Final
+from typing import Any, Dict, Final, List, Optional, Tuple
 
 from .constants import (
     DATA_FRAMES,
@@ -11,6 +11,7 @@ from .constants import (
     MODES,
     MODULE_A,
 )
+from .frame import Request
 from .helpers.base_device import BaseDevice
 from .helpers.parameter import Parameter
 from .mixers import MixersCollection
@@ -21,14 +22,26 @@ ECOSTER_ADDRESS: Final = 0x51
 
 
 class Device(BaseDevice):
-    """Device representation."""
+    """Device representation.
 
-    def __init__(self, data: dict = None, parameters: dict = None):
+    Attributes:
+        bucket -- frame version info storage
+        mixers -- collection of device mixers
+        product -- device product type
+        uid -- device uid string
+        password -- device service password
+        struct -- device regdata schema
+        _is_on -- is device currently turned on
+    """
+
+    def __init__(
+        self, data: Dict[str, Any] = None, parameters: Dict[str, List[int]] = None
+    ):
         """Creates device instance.
 
         Keyword arguments:
-        data -- device data
-        parameters -- editable parameters
+            data -- device data
+            parameters -- editable parameters
         """
         self.__dict__["bucket"] = FrameBucket()
         self.__dict__["mixers"] = MixersCollection(address=self.address)
@@ -39,22 +52,22 @@ class Device(BaseDevice):
         self.__dict__["_is_on"] = False
         super().__init__(data, parameters)
 
-    def set_data(self, data: dict) -> None:
+    def set_data(self, data: Dict[str, Any]) -> None:
         """Sets device data.
 
         Keyword arguments:
-        data -- immutable device attributes
+            data -- immutable device attributes
         """
         self.bucket.fill(data[DATA_FRAMES])
         for name, value in data.items():
             if name in DEVICE_DATA:
                 self._data[name] = value
 
-    def set_parameters(self, parameters: dict) -> None:
+    def set_parameters(self, parameters: Dict[str, List[int]]) -> None:
         """Sets device parameters.
 
         Keyword arguments:
-        parameters -- device changeable parameters
+            parameters -- device changeable parameters
         """
         for name, parameter in parameters.items():
             if name in DEVICE_PARAMS:
@@ -69,7 +82,7 @@ class Device(BaseDevice):
         return bool(self.mixers.mixers)
 
     @property
-    def software(self) -> str | None:
+    def software(self) -> Optional[str]:
         """Returns software version."""
         if MODULE_A in self._data:
             return self._data[MODULE_A]
@@ -97,7 +110,7 @@ class Device(BaseDevice):
         return "Unknown"
 
     @property
-    def changes(self) -> list[Parameter]:
+    def changes(self) -> List[Request]:
         """Returns changed device parameters."""
         changes = self.queue
         changes.extend(self.bucket.queue)
@@ -105,7 +118,7 @@ class Device(BaseDevice):
         return changes
 
     @property
-    def editable_parameters(self) -> list:
+    def editable_parameters(self) -> Tuple[str, ...]:
         """Returns list of editable parameters."""
         return DEVICE_PARAMS
 
@@ -125,19 +138,34 @@ Mixers:
 
 
 class EcoMAX(Device):
-    """ecoMAX device representation."""
+    """ecoMAX device representation.
+
+    Attributes:
+        address -- device address
+    """
 
     address = ECOMAX_ADDRESS
 
 
 class EcoSTER(Device):
-    """ecoSTER device representation."""
+    """ecoSTER device representation.
+
+    Attributes:
+        address -- device address
+    """
 
     address = ECOSTER_ADDRESS
 
 
 class DevicesCollection:
-    """Collection of ecoNET devices."""
+    """Collection of devices.
+
+    Attributes:
+        _classes -- device handler class names
+        _addresses -- device classes mapped with device addresses
+        _instances -- device handler instances
+        _name -- device instances mapped with lowecased class names
+    """
 
     def __init__(self):
         """Creates device collection."""
@@ -146,11 +174,11 @@ class DevicesCollection:
         self._instances = {}
         self._names = {}
 
-    def __getattr__(self, name: str) -> Device | None:
+    def __getattr__(self, name: str) -> Optional[Device]:
         """Gets device by name.""
 
         Keyword arguments:
-        name -- name of device to get
+            name -- name of device to get
         """
         name = name.lower()
         if name in self._names:
@@ -166,15 +194,15 @@ class DevicesCollection:
         """Checks if collection has device for specified address.
 
         Keyword arguments:
-        needle -- address or name of device
+            needle -- address or name of device
         """
         return (needle in self._addresses) or (needle in self._names)
 
-    def get(self, address: int) -> Device | None:
+    def get(self, address: int) -> Optional[Device]:
         """Gets device by address.
 
         Keyword arguments:
-        address -- address of device
+            address -- address of device
         """
         if address not in self._instances:
             try:
