@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from typing import Any, Dict, List, Tuple
 
 from pyplumio import util
 from pyplumio.exceptions import UninitializedParameterError
@@ -11,16 +12,23 @@ from .parameter import Parameter
 
 
 class BaseDevice(ABC):
-    """Base device class."""
+    """Base device class.
+
+    Attributes:
+        _data -- contains immutable device data
+        _parameters --  contains editable parameters
+    """
 
     address: int = BROADCAST_ADDRESS
 
-    def __init__(self, data: dict = None, parameters: dict = None):
+    def __init__(
+        self, data: Dict[str, Any] = None, parameters: Dict[str, List[int]] = None
+    ):
         """Creates device instance.
 
         Keyword arguments:
-        data -- device data
-        parameters -- editable parameters
+            data -- device data
+            parameters -- editable parameters
         """
         self.__dict__["_data"] = {}
         self.__dict__["_parameters"] = {}
@@ -31,13 +39,13 @@ class BaseDevice(ABC):
         if parameters is not None:
             self.set_parameters(parameters)
 
-        self._queue = []
+        self._queue: List[Request] = []
 
     def __getattr__(self, name: str):
         """Gets data or parameter as class attribute.
 
         Keyword arguments:
-        name -- name of property to get
+            name -- name of property to get
         """
         key = name.lower()
         if key in self._data:
@@ -52,8 +60,8 @@ class BaseDevice(ABC):
         """Sets class attribute or device parameter.
 
         Keyword arguments:
-        name -- attribute name
-        value -- attribute value
+            name -- attribute name
+            value -- attribute value
         """
         key = name.lower()
         if key in self._data:
@@ -90,39 +98,39 @@ Parameters:
 """.strip()
 
     @property
-    def queue(self) -> list[Request]:
+    def queue(self) -> List[Request]:
         """Clears and returns changed parameters queue."""
         queue = self._queue
         self._queue = []
         return queue
 
     @property
-    def data(self) -> dict:
+    def data(self) -> Dict[str, Any]:
         """Returns device data."""
         return self._data
 
     @property
-    def parameters(self) -> dict[Parameter]:
+    def parameters(self) -> Dict[str, Parameter]:
         """Returns device parameters."""
         return self._parameters
 
     @abstractmethod
-    def set_data(self, data: dict) -> None:
+    def set_data(self, data: Dict[str, Any]) -> None:
         """Sets device data.
 
         Keyword arguments:
-        data -- device immutable attributes
+            data -- device immutable attributes
         """
 
     @abstractmethod
-    def set_parameters(self, parameters: dict) -> None:
+    def set_parameters(self, parameters: Dict[str, List[int]]) -> None:
         """Sets device parameters.
 
         Keyword arguments:
-        parameters -- device changeable parameters
+            parameters -- device changeable parameters
         """
 
     @property
     @abstractmethod
-    def editable_parameters(self) -> list:
-        """Returns list of editable parameters."""
+    def editable_parameters(self) -> Tuple[str, ...]:
+        """Returns tuple of editable parameters."""
