@@ -1,22 +1,34 @@
 """Contains classes for mixer support."""
 from __future__ import annotations
 
+from typing import Any, Dict, List, Optional, Tuple
+
 from . import util
 from .constants import MIXER_DATA, MIXER_PARAMS
-from .frame import BROADCAST_ADDRESS
+from .frame import BROADCAST_ADDRESS, Request
 from .helpers.base_device import BaseDevice
 from .helpers.parameter import Parameter
 
 
 class Mixer(BaseDevice):
-    """Mixer device representation."""
+    """Mixer device representation.
 
-    def __init__(self, data: dict = None, parameters: dict = None, index: int = 0):
+    Attributes:
+        _index -- mixer index
+        address -- address of device that contains mixer
+    """
+
+    def __init__(
+        self,
+        data: Dict[str, Any] = None,
+        parameters: Dict[str, List[int]] = None,
+        index: int = 0,
+    ):
         """Creates device instance.
 
         Keyword arguments:
-        data -- device data
-        parameters -- editable parameters
+            data -- device data
+            parameters -- editable parameters
         """
         self.__dict__["_index"] = index
         self.__dict__["address"] = BROADCAST_ADDRESS
@@ -42,49 +54,51 @@ Parameters:
 {util.make_list(self._parameters, include_keys = False)}
 """.strip()
 
-    def set_data(self, data: dict) -> None:
+    def set_data(self, data: Dict[str, Any]) -> None:
         """Sets mixer data.
 
         Keyword arguments:
-        data -- mixer immutable attributes
+            data -- mixer immutable attributes
         """
         for name, value in data.items():
             if name in MIXER_DATA:
                 self._data[name] = value
 
-    def set_parameters(self, parameters: dict) -> None:
+    def set_parameters(self, parameters: Dict[str, List[int]]) -> None:
         """Sets mixer parameters.
 
         Keyword arguments:
-        parameters -- mixer changeable parameters
+            parameters -- mixer changeable parameters
         """
         for name, parameter in parameters.items():
             if name in MIXER_PARAMS:
-                self._parameters[name] = Parameter(name, *parameter, self._index)
+                value, min_, max_ = parameter
+                self._parameters[name] = Parameter(name, value, min_, max_, self._index)
 
     @property
-    def editable_parameters(self) -> list:
+    def editable_parameters(self) -> Tuple[str, ...]:
         """Returns list of editable parameters."""
         return MIXER_PARAMS
 
 
 class MixersCollection:
-    """Collection of mixer devices."""
+    """Collection of mixer devices.
 
-    def __init__(self, address: int = BROADCAST_ADDRESS, mixers: list = None):
+    Attributes:
+        _address -- address of device that contains mixers from collection
+        _mixers -- collection of mixers
+    """
+
+    def __init__(self, address: int = BROADCAST_ADDRESS, mixers: List[Mixer] = None):
         """Creates mixer collection instance.
 
         Keyword arguments:
-        address -- address of device containing mixers
-        data -- device data
-        parameters -- editable parameters
+            address -- address of device that contains mixers from collection
+            data -- device data
+            parameters -- editable parameters
         """
         self._address = address
-
-        if mixers is None:
-            self._mixers = []
-        else:
-            self._mixers = mixers
+        self._mixers = mixers if mixers is not None else []
 
     def __repr__(self) -> str:
         """Returns serializable string representation of the class."""
@@ -108,11 +122,11 @@ class MixersCollection:
         """Returns number of mixers in collection."""
         return len(self._mixers)
 
-    def __call__(self, index: int) -> Mixer | None:
+    def __call__(self, index: int) -> Optional[Mixer]:
         """Returns mixer instance by index.
 
         Keyword arguments:
-        index -- mixer index
+            index -- mixer index
         """
         try:
             return self._mixers[index]
@@ -123,7 +137,7 @@ class MixersCollection:
         """Creates mixer instance if not exists and sets mixers data.
 
         Keyword arguments:
-        mixers -- list of mixer data
+            mixers -- list of mixer data
         """
         for index, data in enumerate(mixers):
             try:
@@ -131,12 +145,12 @@ class MixersCollection:
             except IndexError:
                 self._mixers.append(Mixer(data=data, index=index))
 
-    def set_parameters(self, mixers: list):
+    def set_parameters(self, mixers: List[Dict[str, List[int]]]):
         """Creates mixer instance if not exists and
         sets mixers parameters.
 
         Keyword arguments:
-        mixers -- list of mixer parameters
+            mixers -- list of mixer parameters
         """
         for index, parameters in enumerate(mixers):
             try:
@@ -145,12 +159,12 @@ class MixersCollection:
                 self._mixers.append(Mixer(parameters=parameters, index=index))
 
     @property
-    def mixers(self):
+    def mixers(self) -> List[Mixer]:
         """Returns list of mixers."""
         return self._mixers
 
     @property
-    def queue(self):
+    def queue(self) -> List[Request]:
         """Clears and returns changed parameters queue
         for every mixer.
         """
